﻿using System;
using SqlSugar;
using System.Collections.Generic;

namespace ZR.Model.Models.BaseSet
{
    /// <summary>
    /// 基础资料/库位信息表，数据实体对象
    ///
    /// @author admin
    /// @date 2023-04-11
    /// </summary>
    [SugarTable("bas_bin")]
    public class BasBin : BusinessBase
    {
        /// <summary>
        /// 库位Id 系统主键 
        /// </summary>
        [SugarColumn(IsPrimaryKey = true, IsIdentity = true)]
        public long BinId { get; set; }

        /// <summary>
        /// 库位编码 
        /// </summary>
        public string BinCode { get; set; }

        /// <summary>
        /// 库位名称 
        /// </summary>
        public string BinName { get; set; }

        /// <summary>
        /// 库位类型（S存储库位，P拣选库位，V虚拟库位） 
        /// </summary>
        public string BinType { get; set; }

        /// <summary>
        /// 库区编码 
        /// </summary>
        public long RegionId { get; set; }

        /// <summary>
        /// 库位所在排 
        /// </summary>
        public int BinRow { get; set; }

        /// <summary>
        /// 库位所在列 
        /// </summary>
        public int BinColumn { get; set; }

        /// <summary>
        /// 库位所在层 
        /// </summary>
        public int BinLayer { get; set; }

        /// <summary>
        /// 描述 
        /// </summary>
        public string Describe { get; set; }

        /// <summary>
        /// 显示状态（0显示，1隐藏） 
        /// </summary>
        public string Visible { get; set; }

        /// <summary>
        /// 使用状态（0正常，1使用） 
        /// </summary>
        public string Status { get; set; }

        #region 表外字段
        [SugarColumn(IsIgnore = true)]
        public string RegionName { get; set; }
        [SugarColumn(IsIgnore = true)]
        public string RegionCode { get; set; }
        #endregion
    }

    public class BasBinImportTemplate
    {

        /// <summary>
        /// 库位编码 
        /// </summary>
        public string BinCode { get; set; }

        /// <summary>
        /// 库位名称 
        /// </summary>
        public string BinName { get; set; }

        /// <summary>
        /// 库位类型（S存储库位，P拣选库位，V虚拟库位） 
        /// </summary>
        public string BinType { get; set; }

        /// <summary>
        /// 库区编码 
        /// </summary>
        public string RegionId { get; set; }

        /// <summary>
        /// 库位所在排 
        /// </summary>
        public int BinRow { get; set; }

        /// <summary>
        /// 库位所在列 
        /// </summary>
        public int BinColumn { get; set; }

        /// <summary>
        /// 库位所在层 
        /// </summary>
        public int BinLayer { get; set; }

        /// <summary>
        /// 描述 
        /// </summary>
        public string Describe { get; set; }

        /// <summary>
        /// 显示状态（0显示，1隐藏） 
        /// </summary>
        public string Visible { get; set; }

        /// <summary>
        /// 使用状态（0正常，1使用） 
        /// </summary>
        public string Status { get; set; }

    }
}